import {
  MiddlewareConsumer,
  Module,
  NestModule,
  UseFilters,
} from '@nestjs/common';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { NacosService } from './nacos/nacos.service';
import { NacosModule } from './nacos/nacos.module';
import { ConfigModule } from '@nestjs/config';
import { ReportController } from './report/report.controller';
import { ReportModule } from './report/report.module';
import { APP_FILTER, APP_GUARD } from '@nestjs/core';
import { AuthGuard } from './guard/auth.guard';
import { AuthModule } from './auth/auth.module';
import { ClientsModule, Transport } from '@nestjs/microservices';
import * as cookieParser from 'cookie-parser';
import { ForbiddenExceptionFilter } from './filter/forbid.filter';

@Module({
  imports: [
    ConfigModule.forRoot({
      isGlobal: true,
      envFilePath: `.env.${process.env.NODE_ENV}`,
    }),
    ClientsModule.register([
      {
        name: 'Client',
        transport: Transport.RMQ,
        options: {
          urls: ['amqp://localhost:5672'],
          queue: 'cats_queue',
          queueOptions: {
            durable: false,
          },
        },
      },
    ]),
    NacosModule,
    ReportModule,
    AuthModule,
    // DbModule,
  ],
  controllers: [AppController, ReportController],
  providers: [
    AppService,
    NacosService,
    {
      provide: APP_GUARD,
      useClass: AuthGuard,
    },
    {
      provide: APP_FILTER,
      useClass: ForbiddenExceptionFilter,
    },
  ],
})
export class AppModule implements NestModule {
  configure(consumer: MiddlewareConsumer) {
    consumer.apply(cookieParser()).forRoutes('*');
  }
}
